Elliptic curves
=========================

.. toctree::
   :maxdepth: 1

   sage/schemes/elliptic_curves/constructor
   sage/schemes/elliptic_curves/jacobian
   sage/schemes/elliptic_curves/ell_point
   sage/schemes/elliptic_curves/ell_generic
   sage/schemes/elliptic_curves/ell_field
   sage/schemes/elliptic_curves/ell_finite_field
   sage/schemes/elliptic_curves/formal_group

Maps between them

.. toctree::
   :maxdepth: 1

   sage/schemes/elliptic_curves/hom
   sage/schemes/elliptic_curves/hom_composite
   sage/schemes/elliptic_curves/hom_sum
   sage/schemes/elliptic_curves/weierstrass_morphism
   sage/schemes/elliptic_curves/ell_curve_isogeny
   sage/schemes/elliptic_curves/hom_velusqrt
   sage/schemes/elliptic_curves/hom_scalar
   sage/schemes/elliptic_curves/hom_frobenius
   sage/schemes/elliptic_curves/isogeny_small_degree
   sage/schemes/elliptic_curves/mod_poly


Elliptic curves over number fields
----------------------------------

.. toctree::
   :maxdepth: 1

   sage/schemes/elliptic_curves/ell_rational_field
   sage/schemes/elliptic_curves/ec_database

   sage/schemes/elliptic_curves/ell_number_field
   sage/schemes/elliptic_curves/height
   sage/schemes/elliptic_curves/saturation

   sage/schemes/elliptic_curves/ell_torsion
   sage/schemes/elliptic_curves/gal_reps
   sage/schemes/elliptic_curves/gal_reps_number_field
   sage/schemes/elliptic_curves/isogeny_class

   sage/schemes/elliptic_curves/sha_tate
   sage/schemes/elliptic_curves/cm
   sage/schemes/elliptic_curves/Qcurves


The following relate to elliptic curves over local nonarchimedean fields.

.. toctree::
   :maxdepth: 1

   sage/schemes/elliptic_curves/ell_local_data
   sage/schemes/elliptic_curves/kodaira_symbol
   sage/schemes/elliptic_curves/ell_tate_curve
   sage/schemes/elliptic_curves/ell_padic_field

Analytic properties over `\CC`.

.. toctree::
   :maxdepth: 1

   sage/schemes/elliptic_curves/ell_wp
   sage/schemes/elliptic_curves/period_lattice
   sage/schemes/elliptic_curves/period_lattice_region

Modularity and `L`-series over `\QQ`.

.. toctree::
   :maxdepth: 1

   sage/schemes/elliptic_curves/modular_parametrization
   sage/schemes/elliptic_curves/ell_modular_symbols
   sage/schemes/elliptic_curves/mod_sym_num
   sage/schemes/elliptic_curves/lseries_ell
   sage/schemes/elliptic_curves/heegner
   sage/schemes/elliptic_curves/padic_lseries

To be sorted
------------

.. toctree::
   :maxdepth: 1

   sage/schemes/elliptic_curves/BSD
   sage/schemes/elliptic_curves/cardinality
   sage/schemes/elliptic_curves/descent_two_isogeny
   sage/schemes/elliptic_curves/ell_egros
   sage/schemes/elliptic_curves/gp_simon
   sage/schemes/elliptic_curves/kraus
   sage/schemes/elliptic_curves/mod5family
   sage/schemes/elliptic_curves/weierstrass_transform

Hyperelliptic curves
====================

.. toctree::
   :maxdepth: 1

   sage/schemes/hyperelliptic_curves/constructor
   sage/schemes/hyperelliptic_curves/hyperelliptic_generic
   sage/schemes/hyperelliptic_curves/hyperelliptic_finite_field
   sage/schemes/hyperelliptic_curves/hyperelliptic_padic_field
   sage/schemes/hyperelliptic_curves/hyperelliptic_rational_field

   sage/schemes/hyperelliptic_curves/mestre

   sage/schemes/hyperelliptic_curves/monsky_washnitzer
   sage/schemes/hyperelliptic_curves/hypellfrob

   sage/schemes/hyperelliptic_curves/jacobian_generic
   sage/schemes/hyperelliptic_curves/jacobian_g2
   sage/schemes/hyperelliptic_curves/jacobian_homset
   sage/schemes/hyperelliptic_curves/jacobian_morphism
   sage/schemes/hyperelliptic_curves/jacobian_endomorphism_utils

   sage/schemes/hyperelliptic_curves/hyperelliptic_g2
   sage/schemes/hyperelliptic_curves/invariants
   sage/schemes/hyperelliptic_curves/kummer_surface

   sage/interfaces/genus2reduction

.. include:: ../footer.txt
